@@ -1,10 +1,14 @@
 =head1 NAME
 
-DBIx::SQLEngine::Driver::MSSQL - Extends SQLEngine for DBMS Idiosyncrasies
+DBIx::SQLEngine::Driver::MSSQL - Support DBD::ODBC with Microsoft SQL Server
 
 =head1 SYNOPSIS
 
-  my $sqldb = DBIx::SQLEngine->new( 'dbi:MSSQL:test' );
+B<DBI Wrapper>: Adds methods to a DBI database handle.
+
+  my $sqldb = DBIx::SQLEngine->new( 'dbi:odbc:mycnxn' );
+  
+B<Portability Subclasses:> Uses driver's idioms or emulation.
   
   $hash_ary = $sqldb->fetch_select( 
     table => 'students' 
@@ -15,6 +19,14 @@ DBIx::SQLEngine::Driver::MSSQL - Extends SQLEngine for DBMS Idiosyncrasies
 
 This package provides a subclass of DBIx::SQLEngine which compensates for Microsoft SQL Server's idiosyncrasies.
 
+=head2 Under Development
+
+Note: this driver class has been added recently and not yet tested in real-world conditions.
+
+=head2 About Driver Subclasses
+
+You do not need to use this package directly; when you connect to a database, the SQLEngine object is automatically re-blessed in to the appropriate subclass.
+
 =cut
 
 ########################################################################
@@ -26,10 +38,18 @@ use Carp;
 
 ########################################################################
 
-=head2 sql_limit
+=head1 FETCHING DATA (SQL DQL)
+
+=head2 Methods Used By Complex Queries 
+
+=over 4
+
+=item sql_limit()
 
 Adds support for SQL select limit clause.
 
+=back
+
 =cut
 
 sub sql_limit {
@@ -47,21 +67,31 @@ sub sql_limit {
 
 ########################################################################
 
-=head2 do_insert_with_sequence
+########################################################################
+
+=head1 EDITING DATA (SQL DML)
+
+=head2 Insert to Add Data 
+
+=over 4
+
+=item do_insert_with_sequence()
 
   $sqldb->do_insert_with_sequence( $sequence_name, %sql_clauses ) : $row_count
 
 Implemented using _seq_do_insert_postfetch and seq_fetch_current.
 
-=head2 seq_fetch_current
+=item seq_fetch_current
 
   $sqldb->seq_fetch_current( ) : $current_value
 
-Implemented using MSSQL's "select @@IDENTITY". Note that this
+Implemented using MS SQL's "select @@IDENTITY". Note that this
 doesn't fetch the current sequence value for a given table, since
 it doesn't respect the table and field arguments, but merely returns
 the last sequencial value created during this session.
 
+=back
+
 =cut
 
 # $rows = $self->do_insert_with_sequence( $sequence, %clauses );
@@ -79,17 +109,27 @@ sub seq_fetch_current {
 
 ########################################################################
 
-=head2 dbms_create_column_types
+########################################################################
+
+=head1 DEFINING STRUCTURES (SQL DDL)
+
+=head2 Create and Drop Tables
+
+=over 4
+
+=item dbms_create_column_types()
 
   $sqldb->dbms_create_column_types () : %column_type_codes
 
-Implemented using MSSQL's blob and int types.
+Implemented using MS SQL's blob and int types.
 
-=head2 dbms_create_column_text_long_type
+=item dbms_create_column_text_long_type
 
   $sqldb->dbms_create_column_text_long_type () : $col_type_str
 
-Implemented using MSSQL's blob type.
+Implemented using MS SQL's blob type.
+
+=back
 
 =cut
 
@@ -104,14 +144,24 @@ sub dbms_create_column_text_long_type {
 
 ########################################################################
 
-=head2 prepare_execute
+########################################################################
+
+=head1 INTERNAL STATEMENT METHODS (DBI STH)
+
+=head2 Statement Handle Lifecycle 
+
+=over 4
+
+=item prepare_execute()
 
 After the normal prepare_execute cycle, this also sets the sth's LongReadLen to dbms_longreadlen_bufsize().
 
-=head2 dbms_longreadlen_bufsize
+=item dbms_longreadlen_bufsize()
 
 Set to 1_000_000.
 
+=back
+
 =cut
 
 sub dbms_longreadlen_bufsize { 1_000_000 }
